@@ -20,6 +20,7 @@ from python_spartan.services.test import TestService
 from python_spartan.services.inspire import InspireService
 from python_spartan.services.deployment import DeploymentService
 from python_spartan.services.infrastructure import InfrastructureService
+import sys
 
 alembic_cfg = Config("alembic.ini")
 
@@ -297,7 +298,10 @@ def migrate_init(
 def db_seed():
     try:
         print("Seeding the database")
-        subprocess.run(["python", "-m", "database.seeders.database_seeder"])
+        if sys.platform == "darwin":
+            subprocess.run(["python3", "-m", "database.seeders.database_seeder"])
+        else:
+            subprocess.run(["python", "-m", "database.seeders.database_seeder"])
         print("Done")
     except Exception as e:
         print(f"Error seeding the database: {e}")
